@@ -7,6 +7,7 @@ from django.utils.safestring import mark_safe
 from dbtemplates.conf import settings
 from dbtemplates.models import (Template,
     remove_cached_template, add_template_to_cache)
+from dbtemplates.utils.template import check_template_syntax
 
 # Check if django-reversion is installed and use reversions' VersionAdmin
 # as the base admin class if yes
@@ -91,30 +92,54 @@ class TemplateAdmin(TemplateModelAdmin):
     list_filter = ('sites',)
     save_as = True
     search_fields = ('name', 'content')
-    actions = ['invalidate_cache', 'repopulate_cache']
+    actions = ['invalidate_cache', 'repopulate_cache', 'check_syntax']
 
     def invalidate_cache(self, request, queryset):
         for template in queryset:
             remove_cached_template(template)
+        count = queryset.count()
         message = ungettext(
             "Cache of one template successfully invalidated.",
             "Cache of %(count)d templates successfully invalidated.",
-            len(queryset))
-        self.message_user(request, message % {'count': len(queryset)})
+            count)
+        self.message_user(request, message % {'count': count})
     invalidate_cache.short_description = _("Invalidate cache of "
                                            "selected templates")
 
     def repopulate_cache(self, request, queryset):
         for template in queryset:
             add_template_to_cache(template)
+        count = queryset.count()
         message = ungettext(
             "Cache successfully repopulated with one template.",
             "Cache successfully repopulated with %(count)d templates.",
-            len(queryset))
-        self.message_user(request, message % {'count': len(queryset)})
+            count)
+        self.message_user(request, message % {'count': count})
     repopulate_cache.short_description = _("Repopulate cache with "
                                            "selected templates")
 
+    def check_syntax(self, request, queryset):
+        errors = []
+        for template in queryset:
+            valid, error = check_template_syntax(template)
+            if not valid:
+                errors.append('%s: %s' % (template.name, error))
+        if errors:
+            count = len(errors)
+            message = ungettext(
+                "Template syntax check FAILED for %(names)s.",
+                "Template syntax check FAILED for %(count)d templates: %(names)s.",
+                count)
+            self.message_user(request, message %
+                              {'count': count, 'names': ', '.join(errors)})
+        else:
+            count = queryset.count()
+            message = ungettext(
+                "Template syntax OK.",
+                "Template syntax OK for %(count)d templates.", count)
+            self.message_user(request, message % {'count': count})
+    check_syntax.short_description = _("Check template syntax")
+
     def site_list(self, template):
         return ", ".join([site.name for site in template.sites.all()])
     site_list.short_description = _('sites')
