@@ -16,6 +16,15 @@ def get_cache_key(name):
     return 'dbtemplates::%s::%s' % (name, current_site.pk)
 
 
+def get_cache_notfound_key(name):
+    return get_cache_key(name) + '::notfound'
+
+
+def remove_notfound_key(instance):
+    # Remove notfound key as soon as we save the template.
+    cache.delete(get_cache_notfound_key(instance.name))
+
+
 def set_and_return(cache_key, content, display_name):
     # Save in cache backend explicitly if manually deleted or invalidated
     if cache:
@@ -29,6 +38,7 @@ def add_template_to_cache(instance, **kwargs):
     in the database was added or changed.
     """
     remove_cached_template(instance)
+    remove_notfound_key(instance)
     cache.set(get_cache_key(instance.name), instance.content)
 
 
